@@ -4,14 +4,6 @@ import ssl
 
 from lesscode.db.base_connection_pool import BaseConnectionPool
 
-nebula3_gclient_net = None
-nebula3_config = None
-try:
-    nebula3_gclient_net = importlib.import_module("nebula3.gclient.net")
-    nebula3_config = importlib.import_module("nebula3.Config")
-except ImportError as e:
-    raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
-
 
 class NebulaPool(BaseConnectionPool):
     """
@@ -22,6 +14,11 @@ class NebulaPool(BaseConnectionPool):
         pass
 
     def sync_create_pool(self):
+        try:
+            nebula3_gclient_net = importlib.import_module("nebula3.gclient.net")
+            nebula3_config = importlib.import_module("nebula3.Config")
+        except ImportError:
+            raise Exception(f"nebula3 is not exist,run:pip install nebula3-python==3.4.0")
         config = nebula3_config.Config()
         ssl_conf = None
         config.max_connection_pool_size = self.conn_info.max_size
