@@ -19,19 +19,21 @@ class RedisClusterPool(BaseConnectionPool):
         except ImportError:
             raise Exception(f"aioredis is not exist,run:pip install aioredis-cluster==2.3.1")
         if self.conn_info.async_enable:
-            params = self.conn_info.params if self.conn_info.params else {}
-            retry_min_delay = params.get("retry_min_delay")
-            retry_max_delay = params.get("retry_max_delay")
-            max_attempts = params.get("max_attempts")
-            state_reload_interval = params.get("state_reload_interval")
-            follow_cluster = params.get("follow_cluster")
-            idle_connection_timeout = params.get("idle_connection_timeout")
-            username = params.get("username")
+            params = self.conn_info.params
+            if not isinstance(params, dict):
+                params = dict()
+            retry_min_delay = params.pop("retry_min_delay")
+            retry_max_delay = params.pop("retry_max_delay")
+            max_attempts = params.pop("max_attempts")
+            state_reload_interval = params.pop("state_reload_interval")
+            follow_cluster = params.pop("follow_cluster")
+            idle_connection_timeout = params.pop("idle_connection_timeout")
+            username = self.conn_info.user
             password = self.conn_info.password
-            encoding = params.get("encoding")
-            connect_timeout = params.get("connect_timeout")
-            attempt_timeout = params.get("attempt_timeout")
-            ssl = params.get("ssl")
+            encoding = params.pop("encoding")
+            connect_timeout = params.pop("connect_timeout")
+            attempt_timeout = params.pop("attempt_timeout")
+            ssl = params.pop("ssl")
             pool = await aioredis_cluster.create_redis_cluster(startup_nodes=self.conn_info.host,
                                                                retry_min_delay=retry_min_delay,
                                                                retry_max_delay=retry_max_delay,
@@ -46,7 +48,7 @@ class RedisClusterPool(BaseConnectionPool):
                                                                pool_maxsize=self.conn_info.max_size,
                                                                connect_timeout=connect_timeout,
                                                                attempt_timeout=attempt_timeout,
-                                                               ssl=ssl)
+                                                               ssl=ssl, **params)
             return pool
         else:
             raise NotImplementedError
@@ -56,22 +58,21 @@ class RedisClusterPool(BaseConnectionPool):
             rediscluster = importlib.import_module("rediscluster")
         except ImportError:
             raise Exception(f"redis is not exist,run:pip install redis-py-cluster==2.1.3")
-        params = self.conn_info.params if self.conn_info.params else {}
-        init_slot_cache = params.get("init_slot_cache", True) if params else True
-        max_connections_per_node = params.get("init_slot_cache",
-                                              False) if params else False
+        params = self.conn_info.params
+        if not isinstance(params, dict):
+            params = dict()
+        init_slot_cache = params.pop("init_slot_cache", True)
+        max_connections_per_node = params.pop("init_slot_cache", False)
 
-        skip_full_coverage_check = params.get("skip_full_coverage_check",
-                                              False) if params else False
-        nodemanager_follow_cluster = params.get("nodemanager_follow_cluster",
-                                                False) if params else False
-        host_port_remap = params.get("nodemanager_follow_cluster",
-                                     None) if params else None
+        skip_full_coverage_check = params.pop("skip_full_coverage_check", False)
+        nodemanager_follow_cluster = params.pop("nodemanager_follow_cluster", False)
+        host_port_remap = params.pop("nodemanager_follow_cluster", None)
         pool = rediscluster.ClusterConnectionPool(startup_nodes=self.conn_info.host, init_slot_cache=init_slot_cache,
                                                   max_connections=self.conn_info.max_size,
                                                   max_connections_per_node=max_connections_per_node,
                                                   skip_full_coverage_check=skip_full_coverage_check,
                                                   nodemanager_follow_cluster=nodemanager_follow_cluster,
                                                   host_port_remap=host_port_remap, db=self.conn_info.db_name,
-                                                  username=self.conn_info.user, password=self.conn_info.password)
+                                                  username=self.conn_info.user, password=self.conn_info.password,
+                                                  **params)
         return pool
