@@ -11,9 +11,12 @@ class SqlAlchemyPool(BaseConnectionPool):
 
     def sync_create_pool(self):
         db_type = "mysql"
-        if self.conn_info.params:
-            if self.conn_info.params.get("db_type"):
-                db_type = self.conn_info.params.pop("db_type")
+        params = self.conn_info.params
+        if not params or not isinstance(params, dict):
+            params = {}
+        if params:
+            if params.get("db_type"):
+                db_type = params.pop("db_type")
         if db_type == "mysql":
             url = 'mysql+pymysql://{}:{}@{}:{}/{}?charset=utf8mb4'.format(
                 self.conn_info.user, self.conn_info.password, self.conn_info.host, self.conn_info.port,
@@ -36,15 +39,15 @@ class SqlAlchemyPool(BaseConnectionPool):
             sqlalchemy = importlib.import_module("sqlalchemy")
         except ImportError:
             raise Exception(f"sqlalchemy is not exist,run:pip install sqlalchemy==1.4.36")
-        engine = sqlalchemy.create_engine(url, echo=self.conn_info.params.get("echo",
-                                                                              True) if self.conn_info.params else True,
+        echo = params.pop("echo", True)
+        pool_recycle = params.pop("pool_recycle", 3600)
+        max_overflow = params.pop("max_overflow", 0)
+        pool_timeout = params.pop("pool_timeout", 10)
+        pool_pre_ping = params.pop("pool_pre_ping", True)
+        engine = sqlalchemy.create_engine(url, echo=echo,
                                           pool_size=self.conn_info.min_size,
-                                          pool_recycle=self.conn_info.params.get("pool_recycle",
-                                                                                 3600) if self.conn_info.params else 3600,
-                                          max_overflow=self.conn_info.params.get("max_overflow",
-                                                                                 0) if self.conn_info.params else 0,
-                                          pool_timeout=self.conn_info.params.get("pool_timeout",
-                                                                                 10) if self.conn_info.params else 10,
-                                          pool_pre_ping=self.conn_info.params.get("pool_pre_ping",
-                                                                                  True) if self.conn_info.params else True)
+                                          pool_recycle=pool_recycle,
+                                          max_overflow=max_overflow,
+                                          pool_timeout=pool_timeout,
+                                          pool_pre_ping=pool_pre_ping, **params)
         return engine
